# Exercise - Heterogeneous Bin Packing

# DATA
param n;                # Number of items
set N := 1..n;          # Set of items
param Weight {N};       # Weight of each item
param m;                # Number of bins
set M := 1..m;          # Set of bins
param Capacity {M};     # Capacity for each bin
param Cost {M};         # Cost for each bin

# VARIABLES
var x {N,M} binary;		# Assignment variables
var y {M} binary;       # Variables for using the bins

# CONSTRAINTS
# Assignment constraints
subject to Assign {i in N}:
  sum {j in M} x[i,j] = 1;

# Capacity constraints
subject to Cap_constr {j in M}:
  sum {i in N} Weight[i] * x[i,j] <= Capacity[j];

# Linking constraints
subject to Linking {i in N, j in M}:
  x[i,j] <= y[j];
  
# Symmetry breaking constraints
#subject to Symmetry {j in M: j>1}:
#  sum {i in N} Weight[i] * x[i,j] <= sum {i in N} Weight[i] * x[i,j-1];

# OBJECTIVE
# Minimize the total cost of the used bins
minimize z: sum {j in M} Cost[j] * y[j];

##################
data;
param n := 17;
param: Weight  :=   
 1		252	   
 2		250	   
 3		247	   
 4		242	   
 5		228	   
 6		220	   
 7		218	   
 8		199	   
 9		193	   
10		181	   
11		160	   
12		147	   
13		140	   
14		130	   
15		128	   
16		125	   
17		120;
 
param m := 8;
param: Capacity Cost := 
1       600     1000
2       600     1000
3       600     1000
4       600     1000
5       900     1500
6       900     1500
7       900     1500
8       900     1500;

end;

