# Exercise - Bi-dimensional Strip Packing 

# DATA
param n;            # Number of items
set N := 1..n;      # Set of items
param Width {N};    # Width of each item
param Height {N};   # Height of each item
param m;            # Number of shelves
set M := 1..m;      # Set of shelves
param W;            # Width of the strip (of each shelf)

# VARIABLES
var x {N,M} binary; # Assignment variables
var h {M} >=0;      # Height of each shelf

# CONSTRAINTS
# Assignment constraints
subject to Assign {i in N}:
  sum {j in M} x[i,j] = 1; 

# Constraints on the strip width for each shelf
subject to Max_width {j in M}:
  sum {i in N} Width[i] * x[i,j] <= W;
  
# Constraint of the height of each shelf
subject to Min_height {i in N, j in M}:
  Height[i] * x[i,j] <= h[j];

# Symmetry breaking constraints
subject to Symm_break {j in M: j>1}:
  h[j] <= h[j-1];

# OBJECTIVE
minimize z: sum {j in M} h[j];

##################
data;

param n := 15;
param: Width	Height := 
 1		16		16	   
 2		16		 1	   
 3		 8		14	   
 4		13		 2	   
 5		 3		11	   
 6		 6		15	   
 7		11		 7	   
 8		15		 8	   
 9		 5		13	   
10		20		 1	   
11		 2		17	   
12		14		 8	   
13		14		17	   
14		10		 6	   
15		13		11;

param m :=  6;
param W := 40;

end;

